@@ -305,7 +305,7 @@ handle_partial_get (SoupServerMessage *msg)
                         if (content_type) {
                                 soup_message_headers_append_common (part_headers,
                                                                     SOUP_HEADER_CONTENT_TYPE,
-                                                                    content_type, SOUP_HEADER_VALUE_TRUSTED);
+                                                                    content_type);
                         }
                         soup_message_headers_set_content_range (part_headers,
                                                                 ranges[i].start,
@@ -647,21 +647,12 @@ parse_headers (SoupServerMessage *msg,
         /* Handle request body encoding */
         *encoding = soup_message_headers_get_encoding (request_headers);
         if (*encoding == SOUP_ENCODING_UNRECOGNIZED) {
-                g_free (req_path);
                 if (soup_message_headers_get_list_common (request_headers, SOUP_HEADER_TRANSFER_ENCODING))
                         return SOUP_STATUS_NOT_IMPLEMENTED;
                 else
                         return SOUP_STATUS_BAD_REQUEST;
         }
 
-        /* A server MAY reject a request that contains both Content-Length and
-         * Transfer-Encoding or process such a request in accordance with the
-         * Transfer-Encoding alone. Regardless, the server MUST close the connection
-         * after responding to such a request to avoid the potential attacks
-         */
-        if (*encoding == SOUP_ENCODING_CHUNKED && soup_message_headers_get_one_common (request_headers, SOUP_HEADER_CONTENT_LENGTH))
-                soup_message_headers_replace_common (request_headers, SOUP_HEADER_CONNECTION, "close", SOUP_HEADER_VALUE_TRUSTED);
-
         /* Generate correct context for request */
         req_host = soup_message_headers_get_one_common (request_headers, SOUP_HEADER_HOST);
         if (req_host && strchr (req_host, '/')) {
@@ -771,7 +762,7 @@ io_read (SoupServerMessageIOHTTP1 *server_io,
                          * closed when we're done.
                          */
                         soup_server_message_set_status (msg, status, NULL);
-                        soup_message_headers_append_common (request_headers, SOUP_HEADER_CONNECTION, "close", SOUP_HEADER_VALUE_TRUSTED);
+                        soup_message_headers_append_common (request_headers, SOUP_HEADER_CONNECTION, "close");
                         io->read_state = SOUP_MESSAGE_IO_STATE_FINISHING;
                         break;
                 }
